@@ -15,6 +15,7 @@ dosez<-dosez
 Tlastz<-Tlastz
 xlabz<-xlabz
 ylabz<-ylabz
+IndivDP_output<-IndivDP_output
 
 ### file.menu <- c("Linear-up/log-down Trapezoidal Method (default)",
 ###                "All with Linear Trapezoidal Method")
@@ -33,7 +34,7 @@ description_drug()
     ## show(SingleRdata0)  ### close this!  YJ
     SingleRdata1<-Refdata[ do.call(order,Refdata) ,]
     SingleRdata1$conc[SingleRdata1$conc == 0] <- NA
-    SingleRdata1 <- na.omit(SingleRdata1)
+    ### SingleRdata1 <- na.omit(SingleRdata1)   ### for v2.6.1 - IDP output
 
 ## SingleRdata1-->for select 2-6 points
 cat("\n\n")
@@ -45,7 +46,7 @@ cat("\n\n")
      ## show(SingleTdata0)  ### close this!  YJ
      SingleTdata1<-Testdata[ do.call(order,Testdata) ,]
      SingleTdata1$conc[SingleTdata1$conc == 0] <- NA
-     SingleTdata1 <- na.omit(SingleTdata1)
+     ### SingleTdata1 <- na.omit(SingleTdata1)   ### for v2.6.1 - IDP output
 
 SingleRdata<-subset(SingleRdata0,time >=TlastD)
 SingleTdata<-subset(SingleTdata0,time >=TlastD)
@@ -100,7 +101,7 @@ create.products_sum(Totalplot)
       ##  load(comdataname)
       comdata<-readRDS(file.choose())
       comdata<-edit(comdata)
-      comdata<- na.omit(comdata)
+      ### comdata<- na.omit(comdata)   ### for v2.6.1
       colnames(comdata)<-list("subj","time","conc","conc_data","drug")
       cat("\n\n")
       description_drug()
@@ -166,18 +167,32 @@ Singledata<-split(TotalSingledata,list(TotalSingledata$seq,TotalSingledata$prd))
 Ref<-rbind(Singledata[[1]],Singledata[[4]])
 Refdata<-data.frame(subj=Ref$subj,seq= Ref$seq,prd=Ref$prd,drug=c(1),time=Ref$time,conc=Ref$conc)
 SingleRdata<-Refdata[ do.call(order,Refdata) ,]
-### show(SingleRdata)  ### close this!  YJ
+show(SingleRdata)
+if(IndivDP_output){
+### output.indiv(SingleRdata)    ### plan to do... v2.6.1
+### write.csv(SingleRdata,file="singleR.csv",row.names=FALSE)   ### for testing...
+SingleRTdata<-SingleRdata
+indiv_dp.output(SingleRTdata)
+###
+}
 SingleRdata1<-Refdata[ do.call(order,Refdata) ,]
 SingleRdata1$conc[SingleRdata1$conc == 0] <- NA
-SingleRdata1 <- na.omit(SingleRdata1)
+### SingleRdata1 <- na.omit(SingleRdata1)   ### for v2.6.1 - IDP output
 cat("\n\n")
 Test<-rbind(Singledata[[2]],Singledata[[3]])
 Testdata<-data.frame(subj=Test$subj,seq= Test$seq,prd=Test$prd,drug=c(2),time=Test$time,conc=Test$conc)
 SingleTdata<-Testdata[ do.call(order,Testdata) ,]
-## show(SingleTdata)  ### close this!  YJ
+show(SingleTdata)
+if(IndivDP_output){
+### output.indiv(SingleTdata)    ### plan to do...  v2.6.1
+### write.csv(SingleTdata,file="singleT.csv",row.names=FALSE)   ### for testing...
+SingleRTdata<-SingleTdata
+indiv_dp.output(SingleRTdata)
+###
+}
 SingleTdata1<-Testdata[ do.call(order,Testdata) ,]
 SingleTdata1$conc[SingleTdata1$conc == 0] <- NA
-SingleTdata1 <- na.omit(SingleTdata1)
+### SingleTdata1 <- na.omit(SingleTdata1)   ### for v2.6.1 - IDP output
 ###
 ### check icd earlier
 ###
@@ -227,7 +242,7 @@ create.products_sum(Totalplot)
      ##  load(comdataname)
      comdata<-readRDS(file.choose())
      comdata<-edit(comdata)
-     comdata<- na.omit(comdata)
+     ### comdata<- na.omit(comdata)   ### for v2.6.1
      colnames(comdata)<-list("subj","time","conc","conc_data","drug")
      cat("\n\n")
      description_drug()
