@@ -33,7 +33,7 @@ if (pick == 1){
         ## TotalSingledata<-read.csv(TotalSingledata.file,header=TRUE,row.names=NULL,col.names=cnames, sep=",",dec=".")
         TotalSingledata<-read.csv(file.choose(),header=TRUE,row.names=NULL,col.names=cnames, sep=",",dec=".")
         TotalSingledata<-edit(TotalSingledata)
-        TotalSingledata<-na.omit(TotalSingledata)
+        ### TotalSingledata<-na.omit(TotalSingledata)   ### for v2.6.1
         cat("\n\n")
         show(TotalSingledata)
         if(parallel){
@@ -78,7 +78,7 @@ if (pick == 1){
         ## TotalSingledata<-read.csv(TotalSingledata.file,header=TRUE,row.names=NULL,col.names=cnames, sep=";",dec=",")
         TotalSingledata<-read.csv(file.choose(),header=TRUE,row.names=NULL,col.names=cnames, sep=";",dec=",")
         TotalSingledata<-edit(TotalSingledata)
-        TotalSingledata<-na.omit(TotalSingledata)
+        ### TotalSingledata<-na.omit(TotalSingledata)   ### for v2.6.1
         cat("\n\n")
         show(TotalSingledata)
            if(parallel){
@@ -123,7 +123,7 @@ if (pick == 1){
         ## TotalSingledata<-read.csv(TotalSingledata.file,header=TRUE,row.names=NULL,col.names=cnames, sep=";",dec=".")
         TotalSingledata<-read.csv(file.choose(),header=TRUE,row.names=NULL,col.names=cnames, sep=";",dec=".")
         TotalSingledata<-edit(TotalSingledata)
-        TotalSingledata<-na.omit(TotalSingledata)
+        ### TotalSingledata<-na.omit(TotalSingledata)     ### for v2.6.1
         cat("\n\n")
         show(TotalSingledata)
             if(parallel){
@@ -168,7 +168,7 @@ if (pick == 1){
         ##  TotalSingledata<-read.csv(TotalSingledata.file,header=TRUE,row.names=NULL,col.names=cnames, sep=" ",dec=",")
         TotalSingledata<-read.csv(file.choose(),header=TRUE,row.names=NULL,col.names=cnames, sep=" ",dec=",")
         TotalSingledata<-edit(TotalSingledata)
-        TotalSingledata<-na.omit(TotalSingledata)
+        ### TotalSingledata<-na.omit(TotalSingledata)     ### for v2.6.1
         cat("\n\n")
         show(TotalSingledata)
          if(parallel){
@@ -213,7 +213,7 @@ if (pick == 1){
         ##   TotalSingledata<-read.csv(TotalSingledata.file,header=TRUE,row.names=NULL,col.names=cnames, sep=" ",dec=".")
         TotalSingledata<-read.csv(file.choose(),header=TRUE,row.names=NULL,col.names=cnames, sep=" ",dec=".")
         TotalSingledata<-edit(TotalSingledata)
-        TotalSingledata<-na.omit(TotalSingledata)
+        ### TotalSingledata<-na.omit(TotalSingledata)     ### for v2.6.1
         cat("\n\n")
         show(TotalSingledata)
            if(parallel){
@@ -258,7 +258,7 @@ if (pick == 1){
         ##  TotalSingledata<-read.csv(TotalSingledata.file,header=TRUE,row.names=NULL,col.names=cnames, sep="\t",dec=",")
         TotalSingledata<-read.csv(file.choose(),header=TRUE,row.names=NULL,col.names=cnames, sep="\t",dec=",")
         TotalSingledata<-edit(TotalSingledata)
-        TotalSingledata<-na.omit(TotalSingledata)
+        ### TotalSingledata<-na.omit(TotalSingledata)     ### for v2.6.1
         cat("\n\n")
         show(TotalSingledata)
             if(parallel){
@@ -303,7 +303,7 @@ if (pick == 1){
         ##   TotalSingledata<-read.csv(TotalSingledata.file,header=TRUE,row.names=NULL,col.names=cnames, sep="\t",dec=".")
         TotalSingledata<-read.csv(file.choose(),header=TRUE,row.names=NULL,col.names=cnames, sep="\t",dec=".")
         TotalSingledata<-edit(TotalSingledata)
-        TotalSingledata<-na.omit(TotalSingledata)
+        ### TotalSingledata<-na.omit(TotalSingledata)     ### for v2.6.1
         cat("\n\n")
         show(TotalSingledata)
             if(parallel){
@@ -348,7 +348,7 @@ if (pick == 1){
         ##   TotalSingledata<-read.csv(TotalSingledata.file,header=TRUE,row.names=NULL,col.names=cnames, sep=":",dec=",")
         TotalSingledata<-read.csv(file.choose(),header=TRUE,row.names=NULL,col.names=cnames, sep=":",dec=",")
         TotalSingledata<-edit(TotalSingledata)
-        TotalSingledata<-na.omit(TotalSingledata)
+        ### TotalSingledata<-na.omit(TotalSingledata)     ### for v2.6.1
         cat("\n\n")
         show(TotalSingledata)
             if(parallel){
@@ -393,7 +393,7 @@ if (pick == 1){
         ##  TotalSingledata<-read.csv(TotalSingledata.file,header=TRUE,row.names=NULL,col.names=cnames, sep=":",dec=".")
         TotalSingledata<-read.csv(file.choose(),header=TRUE,row.names=NULL,col.names=cnames, sep=":",dec=".")
         TotalSingledata<-edit(TotalSingledata)
-        TotalSingledata<-na.omit(TotalSingledata)
+        ### TotalSingledata<-na.omit(TotalSingledata)     ### for v2.6.1
         cat("\n\n")
         show(TotalSingledata)
         if(parallel){
