@@ -27,7 +27,7 @@ if (pick == 1){
        }
      }
      TotalSingledata<-edit(TotalSingledata)
-     TotalSingledata<- na.omit(TotalSingledata)
+     ### TotalSingledata<- na.omit(TotalSingledata)    ### v2.6.1
      show(TotalSingledata)
      cat("\n")
       cat("Enter the file name (no extension!):\n")
@@ -131,7 +131,7 @@ else {
 ##     load(TotalSinglename)
      TotalSingledata<-readRDS(file.choose())  # musch better than using load()
      TotalSingledata<-edit(TotalSingledata)
-     TotalSingledata<- na.omit(TotalSingledata)
+     ### TotalSingledata<-na.omit(TotalSingledata)   ### v2.6.1
          if(parallel){
          colnames(TotalSingledata)<-list("subj", "drug","time", "conc")
          }
