@@ -22,6 +22,7 @@ dosez<-dosez
 Tlastz<-Tlastz
 xlabz<-xlabz
 ylabz<-ylabz
+IndivDP_output<-IndivDP_output
 
 ### 
 ### file.menu <- c("Linear-up/log-down Trapezoidal Method (default)",
@@ -42,16 +43,9 @@ ylabz<-ylabz
 ###   pick <- menu(file.menu, title = "  <<Method Selections for Lambda_z Estimation>> ", graphics=TRUE)
     description_NCAinput()
     
- if(replicated){
+if(replicated){                      ### not for v2.6.1's IDP output yet... -YJ
     filelocxx <- system.file("extdata", "Replicateddata.rda", package="bear")
     load(filelocxx)  ## because it is a *.rda data file
-    ## saveRDS(Replicateddata,"Replicateddata_demo.RData")
-    if(file.exists("SingleRep_demo.csv")){
-       write.csv(Replicateddata,file="SingleRep_demo_02.csv",row.names=FALSE)}
-    else{write.csv(Replicateddata,file="SingleRep_demo.csv",row.names=FALSE)}
-    if(file.exists("SingleRep_demo.RData")){
-       saveRDS(Replicateddata,file="SingleRep_demo_02.RData")}
-    else{saveRDS(Replicateddata,file="SingleRep_demo.RData")}             
 
     with(entertitle.demo(), {
      description_RepNCAinput()  
@@ -90,20 +84,20 @@ Refdata<-data.frame(subj=Singledata[[1]]$subj, seq= Singledata[[1]]$seq, prd=Sin
                     drug=Singledata[[1]]$drug, time=Singledata[[1]]$time, conc=Singledata[[1]]$conc,
                     code=Singledata[[1]]$code)
 SingleRdata<-Refdata[ do.call(order, Refdata) ,]
-
+show(SingleRdata);cat("\n\n")  ### ;write.csv(SingleRdata,file="RepSingleRdata.csv",row.names=FALSE)
 SingleRdata1<-Refdata[ do.call(order, Refdata) ,]
 SingleRdata1$conc[SingleRdata1$conc == 0] <- NA
-SingleRdata1 <- na.omit(SingleRdata1)
+### SingleRdata1 <- na.omit(SingleRdata1)     ### for v2.6.1 but no IDP output function yet
 ##SingleRdata1-->for select 3 points
 cat("\n\n")
 Testdata<-data.frame(subj=Singledata[[2]]$subj, seq=Singledata[[2]]$seq, prd=Singledata[[2]]$prd,
                      drug=Singledata[[2]]$drug, time=Singledata[[2]]$time, conc=Singledata[[2]]$conc,
                      code=Singledata[[2]]$code)
 SingleTdata<-Testdata[ do.call(order, Testdata) ,]
-
+show(SingleTdata)  ### ;write.csv(SingleTdata,file="RepSingleTdata.csv",row.names=FALSE)
 SingleTdata1<-Testdata[ do.call(order, Testdata) ,]
 SingleTdata1$conc[SingleTdata1$conc == 0] <- NA
-SingleTdata1 <- na.omit(SingleTdata1)
+### SingleTdata1 <- na.omit(SingleTdata1)     ### for v2.6.1 but no IDP output function yet
 
 Totalplot<- rbind(SingleRdata,SingleTdata)              
 ###
@@ -111,43 +105,32 @@ create.products_sum(Totalplot)
 ###
 
    if (lambda_z_calc == 5){
-        show(SingleRdata)
-        show(SingleTdata)
         cat("\n")
         RepNCAselectdemo(Totalplot,SingleRdata1,SingleTdata1,Dose,SingleRdata,SingleTdata,xaxis, yaxis)
         }
     else {
     if (lambda_z_calc == 0){
-        show(SingleRdata)
-        show(SingleTdata)
         cat("\n")
         RepARSdemo(Dose, xaxis,yaxis,Totalplot,SingleRdata,SingleTdata,SingleRdata1,SingleTdata1)
        }
     else {
     if (lambda_z_calc == 1){
-        show(SingleRdata)
-        show(SingleTdata)
         cat("\n")
         RepAICdemo(Dose, xaxis,yaxis,Totalplot,SingleRdata,SingleTdata,SingleRdata1,SingleTdata1)
        }
     else {
     if (lambda_z_calc == 2){
-        show(SingleRdata)
-        show(SingleTdata)
         cat("\n")
        RepTTTdemo(Dose, xaxis,yaxis,Totalplot,SingleRdata,SingleTdata,SingleRdata1,SingleTdata1)
        }
     else {
     if (lambda_z_calc == 3){
-        show(SingleRdata)
         show(SingleTdata)
         cat("\n")
         RepTTTARSdemo(Dose, xaxis,yaxis,Totalplot,SingleRdata,SingleTdata,SingleRdata1,SingleTdata1)
          }
    else {
     if (lambda_z_calc == 4){
-        show(SingleRdata)
-        show(SingleTdata)
         cat("\n")
        RepTTTAICdemo(Dose, xaxis,yaxis,Totalplot,SingleRdata,SingleTdata,SingleRdata1,SingleTdata1)
         }
@@ -163,13 +146,6 @@ create.products_sum(Totalplot)
      if(multiple){
      filelocxx <- system.file("extdata", "MultipleParadata.rda", package="bear")
      load(filelocxx)  ## because it is a *.rda data file
-     ## saveRDS(MultipleParadata,"MultipleParadata_demo.RData")
-     if(file.exists("MultiplePara_demo.csv")){
-        write.csv(MultipleParadata,file="MultiplePara_demo_02.csv",row.names=FALSE)}
-     else{write.csv(MultipleParadata,file="MultiplePara_demo.csv",row.names=FALSE)}
-     if(file.exists("MultiplePara_demo.RData")){
-        saveRDS(MultipleParadata,file="MultiplePara_demo_02.RData")}
-     else{saveRDS(MultipleParadata,file="MultiplePara_demo.RData")}                  
      
      with(Multiplentertitle.demo(), {
      description_ParaNCAinput()  
@@ -180,7 +156,7 @@ create.products_sum(Totalplot)
        SingleRdata0<-Refdata[ do.call(order, Refdata) ,]
        SingleRdata1<-Refdata[ do.call(order, Refdata) ,]
        SingleRdata1$conc[SingleRdata1$conc == 0] <- NA
-       SingleRdata1 <- na.omit(SingleRdata1)
+       ### SingleRdata1 <- na.omit(SingleRdata1)     ### for v2.6.1 IDP output function
       
       Test<-rbind(Singledata[[2]])
       Testdata<-data.frame(subj=Test$subj, drug=Test$drug, time=Test$time, conc=Test$conc)
@@ -188,10 +164,20 @@ create.products_sum(Totalplot)
        SingleTdata0<-Testdata[ do.call(order, Testdata) ,]
        SingleTdata1<-Testdata[ do.call(order, Testdata) ,]
        SingleTdata1$conc[SingleTdata1$conc == 0] <- NA
-       SingleTdata1 <- na.omit(SingleTdata1)
+       ### SingleTdata1 <- na.omit(SingleTdata1)     ### for v2.6.1 IDP output function
 
       SingleRdata<-subset(SingleRdata0, time >=TlastD)
+      show(SingleRdata0);cat("\n\n")
+        if(IndivDP_output){
+        SingleRTdata<-SingleRdata
+        indiv_dp.output(SingleRTdata)
+        }              
       SingleTdata<-subset(SingleTdata0, time >=TlastD)
+      show(SingleTdata0)
+        if(IndivDP_output){
+        SingleRTdata<-SingleTdata
+        indiv_dp.output(SingleRTdata)
+        }              
       
       Totalplot<- rbind(SingleRdata,SingleTdata)
 ###
@@ -199,44 +185,26 @@ create.products_sum(Totalplot)
 ###
 
     if (lambda_z_calc == 5){
-        show(SingleRdata)
-        show(SingleTdata)
-        cat("\n")
         MultipleParaNCAselectdemo(Totalplot,SingleRdata1,SingleTdata1, Dose,SingleRdata,SingleTdata,xaxis, yaxis, Tau, TlastD,SingleRdata0,SingleTdata0)
         }
     else {
     if (lambda_z_calc == 0){
-        show(SingleRdata)
-        show(SingleTdata)
-        cat("\n")
        MultipleParaARSdemo(Totalplot,SingleRdata1,SingleTdata1, Dose,SingleRdata,SingleTdata,xaxis, yaxis, Tau, TlastD,SingleRdata0,SingleTdata0)
        }
     else {
     if (lambda_z_calc == 1){
-        show(SingleRdata)
-        show(SingleTdata)
-        cat("\n")
        MultipleParaAICdemo(Totalplot,SingleRdata1,SingleTdata1, Dose,SingleRdata,SingleTdata,xaxis, yaxis, Tau, TlastD,SingleRdata0,SingleTdata0)
        }
     else {
     if (lambda_z_calc == 2){
-        show(SingleRdata)
-        show(SingleTdata)
-        cat("\n")
        MultipleParaTTTdemo(Totalplot,SingleRdata1,SingleTdata1, Dose,SingleRdata,SingleTdata,xaxis, yaxis, Tau, TlastD,SingleRdata0,SingleTdata0)
        }
     else {
     if (lambda_z_calc == 3){
-        show(SingleRdata)
-        show(SingleTdata)
-        cat("\n")
        MultipleParaTTTARSdemo(Totalplot,SingleRdata1,SingleTdata1, Dose,SingleRdata,SingleTdata,xaxis, yaxis, Tau, TlastD,SingleRdata0,SingleTdata0)
        }
    else {
     if (lambda_z_calc == 4){
-        show(SingleRdata)
-        show(SingleTdata)
-        cat("\n")
        MultipleParaTTTAICdemo(Totalplot,SingleRdata1,SingleTdata1, Dose,SingleRdata,SingleTdata,xaxis, yaxis, Tau, TlastD,SingleRdata0,SingleTdata0)
        }
         }
@@ -249,13 +217,6 @@ create.products_sum(Totalplot)
      else{
      filelocxx <- system.file("extdata", "Paralleldata.rda", package="bear")
      load(filelocxx)  ## because it is a *.rda data file
-     ## saveRDS(Paralleldata,"Paralleldata_demo.RData")
-     if(file.exists("SinglePara_demo.csv")){
-        write.csv(Paralleldata,file="SinglePara_demo_02.csv",row.names=FALSE)}
-     else{write.csv(Paralleldata,file="SinglePara_demo.csv",row.names=FALSE)}
-     if(file.exists("SinglePara_demo.RData")){
-        saveRDS(Paralleldata,file="SinglePara_demo_02.RData")}
-     else{saveRDS(Paralleldata,file="SinglePara_demo.RData")}
      
      with(entertitle.demo(), {
      description_ParaNCAinput()  
@@ -263,62 +224,52 @@ create.products_sum(Totalplot)
       Ref<-Singledata[[1]]
       Refdata<-data.frame(subj=Ref$subj,drug=Ref$drug,time=Ref$time, conc=Ref$conc)
       SingleRdata<-Refdata[ do.call(order, Refdata) ,]
-      
+      show(SingleRdata);cat("\n\n")
+      if(IndivDP_output){
+      SingleRTdata<-SingleRdata
+      indiv_dp.output(SingleRTdata)
+      }
       SingleRdata1<-Refdata[ do.call(order, Refdata) ,]
       SingleRdata1$conc[SingleRdata1$conc == 0] <- NA
-      SingleRdata1 <- na.omit(SingleRdata1)
+      ### SingleRdata1 <- na.omit(SingleRdata1)     ### for v2.6.1 IDP output function
         cat("\n\n")
       Test<-rbind(Singledata[[2]])
       Testdata<-data.frame(subj=Test$subj, drug=Test$drug, time=Test$time, conc=Test$conc)
       SingleTdata<-Testdata[ do.call(order, Testdata) ,]
-      
+      show(SingleTdata)
+      if(IndivDP_output){
+      SingleRTdata<-SingleTdata
+      indiv_dp.output(SingleRTdata)
+      }
       SingleTdata1<-Testdata[ do.call(order, Testdata) ,]
       SingleTdata1$conc[SingleTdata1$conc == 0] <- NA
-      SingleTdata1 <- na.omit(SingleTdata1)
+      ### SingleTdata1 <- na.omit(SingleTdata1)     ### for v2.6.1 IDP output function
       Totalplot<- rbind(SingleRdata,SingleTdata)
 ###
 create.products_sum(Totalplot)
 ###
       
     if (lambda_z_calc == 5){
-        show(SingleRdata)
-        show(SingleTdata)
-        cat("\n")
         ParaNCAselectdemo(Totalplot,SingleRdata1,SingleTdata1,Dose,SingleRdata,SingleTdata,xaxis, yaxis)
         }
     else {
     if (lambda_z_calc == 0){
-      show(SingleRdata)
-        show(SingleTdata)
-        cat("\n")
        ParaARSdemo(Dose, xaxis,yaxis,Totalplot,SingleRdata,SingleTdata,SingleRdata1,SingleTdata1)
        }
     else {
     if (lambda_z_calc == 1){
-        show(SingleRdata)
-        show(SingleTdata)
-        cat("\n")
        ParaAICdemo(Dose, xaxis,yaxis,Totalplot,SingleRdata,SingleTdata,SingleRdata1,SingleTdata1)
        }
     else {
     if (lambda_z_calc == 2){
-        show(SingleRdata)
-        show(SingleTdata)
-        cat("\n")
        ParaTTTdemo(Dose, xaxis,yaxis,Totalplot,SingleRdata,SingleTdata,SingleRdata1,SingleTdata1)
        }
     else {
     if (lambda_z_calc == 3){
-        show(SingleRdata)
-        show(SingleTdata)
-        cat("\n")
        ParaTTTARSdemo(Dose, xaxis,yaxis,Totalplot,SingleRdata,SingleTdata,SingleRdata1,SingleTdata1)
        }
    else {
     if (lambda_z_calc == 4){
-        show(SingleRdata)
-        show(SingleTdata)
-        cat("\n")
        ParaTTTAICdemo(Dose, xaxis,yaxis,Totalplot,SingleRdata,SingleTdata,SingleRdata1,SingleTdata1)
        }
         }
@@ -333,12 +284,6 @@ else{
   if(multiple){
      filelocxx <- system.file("extdata", "Multipledata.rda", package="bear")
      load(filelocxx)
-     if(file.exists("Multiple2x2x2_demo.csv")){
-        write.csv(Multipledata,file="Multiple2x2x2_demo_02.csv",row.names=FALSE)}
-     else{write.csv(Multipledata,file="Multiple2x2x2_demo.csv",row.names=FALSE)}
-     if(file.exists("Multiple2x2x2_demo.RData")){
-        saveRDS(Multipledata,file="Multiple2x2x2_demo_02.RData")}
-     else{saveRDS(Multipledata,file="Multiple2x2x2_demo.RData")}     
      
      with(Multiplentertitle.demo(), {
      description_NCAinput()  
@@ -350,7 +295,7 @@ else{
        SingleRdata0<-Refdata[ do.call(order, Refdata) ,]
        SingleRdata1<-Refdata[ do.call(order, Refdata) ,]
        SingleRdata1$conc[SingleRdata1$conc == 0] <- NA
-       SingleRdata1 <- na.omit(SingleRdata1)
+       ### SingleRdata1 <- na.omit(SingleRdata1)     ### for v2.6.1 IDP output function
         cat("\n\n")
       Test<-rbind(Singledata[[2]],Singledata[[3]])
       Testdata<-data.frame(subj=Test$subj, seq= Test$seq, prd=Test$prd, drug=c(2), 
@@ -358,54 +303,46 @@ else{
        SingleTdata0<-Testdata[ do.call(order, Testdata) ,]
        SingleTdata1<-Testdata[ do.call(order, Testdata) ,]
        SingleTdata1$conc[SingleTdata1$conc == 0] <- NA
-       SingleTdata1 <- na.omit(SingleTdata1)
+       ### SingleTdata1 <- na.omit(SingleTdata1)     ### for v2.6.1 IDP output function
       
      SingleRdata<-subset(SingleRdata0, time >=TlastD)
+     show(SingleRdata0);cat("\n\n")
+      if(IndivDP_output){
+      SingleRTdata<-SingleRdata
+      indiv_dp.output(SingleRTdata)
+      }     
      SingleTdata<-subset(SingleTdata0, time >=TlastD)
+     show(SingleTdata0)
+      if(IndivDP_output){
+      SingleRTdata<-SingleTdata
+      indiv_dp.output(SingleRTdata)
+      }     
      Totalplot<- rbind(SingleRdata0,SingleTdata0)
 ###
 create.products_sum(Totalplot)
 ###
       
     if (lambda_z_calc == 5){
-        show(SingleRdata0)
-        show(SingleTdata0)
-        cat("\n")
         MultipleNCAselectdemo(Totalplot,SingleRdata1,SingleTdata1, Dose,SingleRdata,SingleTdata,xaxis, yaxis, Tau, TlastD,SingleRdata0,SingleTdata0) 
         }
     else {
     if (lambda_z_calc == 0){
-        show(SingleRdata0)
-        show(SingleTdata0)
-        cat("\n")
        MultipleARSdemo(Totalplot,SingleRdata1,SingleTdata1, Dose,SingleRdata,SingleTdata,xaxis, yaxis, Tau, TlastD,SingleRdata0,SingleTdata0) 
        }
     else {
     if (lambda_z_calc == 1){
-        show(SingleRdata0)
-        show(SingleTdata0)
-        cat("\n")
        MultipleAICdemo(Totalplot,SingleRdata1,SingleTdata1, Dose,SingleRdata,SingleTdata,xaxis, yaxis, Tau, TlastD,SingleRdata0,SingleTdata0) 
        }
     else {
     if (lambda_z_calc == 2){
-        show(SingleRdata0)
-        show(SingleTdata0)
-        cat("\n")
        MultipleTTTdemo(Totalplot,SingleRdata1,SingleTdata1, Dose,SingleRdata,SingleTdata,xaxis, yaxis, Tau, TlastD,SingleRdata0,SingleTdata0) 
        }
     else {
     if (lambda_z_calc == 3){
-        show(SingleRdata0)
-        show(SingleTdata0)
-        cat("\n")
        MultipleTTTARSdemo(Totalplot,SingleRdata1,SingleTdata1, Dose,SingleRdata,SingleTdata,xaxis, yaxis, Tau, TlastD,SingleRdata0,SingleTdata0) 
        }
    else {
     if (lambda_z_calc == 4){
-        show(SingleRdata0)
-        show(SingleTdata0)
-        cat("\n")
        MultipleTTTAICdemo(Totalplot,SingleRdata1,SingleTdata1, Dose,SingleRdata,SingleTdata,xaxis, yaxis, Tau, TlastD,SingleRdata0,SingleTdata0) 
        }
         }
@@ -416,14 +353,10 @@ create.products_sum(Totalplot)
    })
   }
   else{   
-     filelocxx <- system.file("extdata", "TotalSingledata.rda", package="bear")
+     filelocxx <- system.file("extdata", "TotalSingledata.rda", package="bear")  ### both work well.
      load(filelocxx)
-     if(file.exists("Single2x2x2_demo.csv")){
-        write.csv(TotalSingledata,file="Single2x2x2_demo_02.csv",row.names=FALSE)}
-     else{write.csv(TotalSingledata,file="Single2x2x2_demo.csv",row.names=FALSE)}
-     if(file.exists("Single2x2x2_demo.RData")){
-        saveRDS(TotalSingledata,file="Single2x2x2_demo_02.RData")}
-     else{saveRDS(TotalSingledata,file="Single2x2x2_demo.RData")}          
+     ### filelocxx <- system.file("extdata", "Single2x2x2.rda", package="bear")  ### v2.6.1 to test IDP function
+     ### TotalSingledata<-readRDS(filelocxx)                                     ### v2.6.1 to test IDP function
 
      with(entertitle.demo(), {
      description_NCAinput()  
@@ -431,62 +364,53 @@ create.products_sum(Totalplot)
       Ref<-rbind(Singledata[[1]],Singledata[[4]])
       Refdata<-data.frame(subj=Ref$subj, seq= Ref$seq, prd=Ref$prd, drug=c(1), time=Ref$time, conc=Ref$conc)
       SingleRdata<-Refdata[ do.call(order, Refdata) ,]
-     
+      show(SingleRdata);cat("\n\n")
+      ### IndivDP_output;readline("... pause here\n\n")
+      if(IndivDP_output){
+      SingleRTdata<-SingleRdata
+      indiv_dp.output(SingleRTdata)
+      }
       SingleRdata1<-Refdata[ do.call(order, Refdata) ,]
       SingleRdata1$conc[SingleRdata1$conc == 0] <- NA
-      SingleRdata1 <- na.omit(SingleRdata1)
+      ### SingleRdata1 <- na.omit(SingleRdata1)     ### for v2.6.1 IDP output function
         cat("\n\n")
       Test<-rbind(Singledata[[2]],Singledata[[3]])
       Testdata<-data.frame(subj=Test$subj, seq= Test$seq, prd=Test$prd, drug=c(2), time=Test$time, conc=Test$conc)
       SingleTdata<-Testdata[ do.call(order, Testdata) ,]
-     
+      show(SingleTdata)
+      if(IndivDP_output){
+      SingleRTdata<-SingleTdata
+      indiv_dp.output(SingleRTdata)
+      }      
       SingleTdata1<-Testdata[ do.call(order, Testdata) ,]
       SingleTdata1$conc[SingleTdata1$conc == 0] <- NA
-      SingleTdata1 <- na.omit(SingleTdata1)
+      ### SingleTdata1 <- na.omit(SingleTdata1)     ### for v2.6.1 IDP output function
       Totalplot<- rbind(SingleRdata,SingleTdata)
 ###
 create.products_sum(Totalplot)
 ###
       
     if (lambda_z_calc == 5){
-        show(SingleRdata)
-        show(SingleTdata)
-        cat("\n")
         NCAselectdemo(Totalplot,SingleRdata1,SingleTdata1,Dose,SingleRdata,SingleTdata,xaxis, yaxis)
         }
     else {
     if (lambda_z_calc == 0){
-        show(SingleRdata)
-        show(SingleTdata)
-        cat("\n")
        ARSdemo(Dose, xaxis,yaxis,Totalplot,SingleRdata,SingleTdata,SingleRdata1,SingleTdata1)
        }
     else {
     if (lambda_z_calc == 1){
-        show(SingleRdata)
-        show(SingleTdata)
-        cat("\n")
        AICdemo(Dose, xaxis,yaxis,Totalplot,SingleRdata,SingleTdata,SingleRdata1,SingleTdata1)
        }
     else {
     if (lambda_z_calc == 2){
-        show(SingleRdata)
-        show(SingleTdata)
-        cat("\n")
        TTTdemo(Dose, xaxis,yaxis,Totalplot,SingleRdata,SingleTdata,SingleRdata1,SingleTdata1)
        }
     else {
     if (lambda_z_calc == 3){
-        show(SingleRdata)
-        show(SingleTdata)
-        cat("\n")
        TTTARSdemo(Dose, xaxis,yaxis,Totalplot,SingleRdata,SingleTdata,SingleRdata1,SingleTdata1)
        }
    else {
     if (lambda_z_calc == 4){
-        show(SingleRdata)
-        show(SingleTdata)
-        cat("\n")
        TTTAICdemo(Dose, xaxis,yaxis,Totalplot,SingleRdata,SingleTdata,SingleRdata1,SingleTdata1)
        }
         }
