@@ -22,6 +22,7 @@ dosez<-dosez
 Tlastz<-Tlastz
 xlabz<-xlabz
 ylabz<-ylabz
+IndivDP_output<-IndivDP_output
 
 ### file.menu <- c("Linear-up/log-down Trapezoidal Method (default)",
 ###                "All with Linear Trapezoidal Method")
@@ -40,16 +41,9 @@ ylabz<-ylabz
 ###                  "Quit")
 ###  cat("\n")
 ###   pick <- menu(file.menu, title = " <<Method Selections for Lambda_z Estimation>> ", graphics=TRUE)
-  if(replicated){
+if(replicated){
     filelocxx <- system.file("extdata", "Replicateddata.rda", package="bear")
     load(filelocxx)  ## because it is a *.rda data file
-    ### save the dataset for testing...  -YJ
-    if(file.exists("SingleRep_demo.csv")){
-         write.csv(Replicateddata,file="SingleRep_demo_02.csv",row.names=FALSE)}
-    else{write.csv(Replicateddata,file="SingleRep_demo.csv",row.names=FALSE)}
-    if(file.exists("SingleRep_demo.RData")){
-         saveRDS(Replicateddata,file="SingleRep_demo_02.RData")}
-    else{saveRDS(Replicateddata,file="SingleRep_demo.RData")}
 
     with(entertitle.demo(), {
      description_RepNCAinput()  
@@ -89,20 +83,20 @@ Refdata<-data.frame(subj=Singledata[[1]]$subj, seq= Singledata[[1]]$seq, prd=Sin
                     drug=Singledata[[1]]$drug, time=Singledata[[1]]$time, conc=Singledata[[1]]$conc,
                     code=Singledata[[1]]$code)
 SingleRdata<-Refdata[ do.call(order, Refdata) ,]
-
+show(SingleRdata);cat("\n\n")
 SingleRdata1<-Refdata[ do.call(order, Refdata) ,]
 SingleRdata1$conc[SingleRdata1$conc == 0] <- NA
-SingleRdata1 <- na.omit(SingleRdata1)
+### SingleRdata1 <- na.omit(SingleRdata1)     ### for v2.6.1 but no IDP output function yet
 ##SingleRdata1-->for select 3 points
 cat("\n\n")
 Testdata<-data.frame(subj=Singledata[[2]]$subj, seq=Singledata[[2]]$seq, prd=Singledata[[2]]$prd,
                      drug=Singledata[[2]]$drug, time=Singledata[[2]]$time, conc=Singledata[[2]]$conc,
                      code=Singledata[[2]]$code)
 SingleTdata<-Testdata[ do.call(order, Testdata) ,]
-
+show(SingleTdata)
 SingleTdata1<-Testdata[ do.call(order, Testdata) ,]
 SingleTdata1$conc[SingleTdata1$conc == 0] <- NA
-SingleTdata1 <- na.omit(SingleTdata1)
+### SingleTdata1 <- na.omit(SingleTdata1)     ### for v2.6.1 but no IDP output function yet
 
 Totalplot<- rbind(SingleRdata,SingleTdata)
 ###
@@ -111,49 +105,31 @@ create.products_sum(Totalplot)
       
    if (lambda_z_calc == 5){
         description_pointselect()
-      cat("\n")
-        ## show(SingleRdata)   ### close this!  YJ
-        ## show(SingleTdata)
         RepNCAselectdemo.MIX(Totalplot,SingleRdata1,SingleTdata1,Dose,SingleRdata,SingleTdata,xaxis, yaxis)
         RepNCA.MIXmenu()
         }
     else {
     if (lambda_z_calc == 0){
-        cat("\n")
-        ## show(SingleRdata)   ### close this!  YJ
-        ## show(SingleTdata)
         RepARS.MIX(Dose, xaxis,yaxis,Totalplot,SingleRdata,SingleTdata,SingleRdata1,SingleTdata1)
         RepNCA.MIXmenu()
        }
     else {
     if (lambda_z_calc == 1){
-        cat("\n")
-        ## show(SingleRdata)   ### close this!  YJ
-        ## show(SingleTdata)
         RepAIC.MIX(Dose, xaxis,yaxis,Totalplot,SingleRdata,SingleTdata,SingleRdata1,SingleTdata1)
         RepNCA.MIXmenu()
        }
     else {
     if (lambda_z_calc == 2){
-        cat("\n")
-        ## show(SingleRdata)   ### close this!  YJ
-        ## show(SingleTdata)
         RepTTT.MIX(Dose, xaxis,yaxis,Totalplot,SingleRdata,SingleTdata,SingleRdata1,SingleTdata1)
         RepNCA.MIXmenu()
        }
     else {
     if (lambda_z_calc == 3){
-        cat("\n")
-        ## show(SingleRdata)   ### close this!  YJ
-        ## show(SingleTdata)
         RepTTTARS.MIX(Dose, xaxis,yaxis,Totalplot,SingleRdata,SingleTdata,SingleRdata1,SingleTdata1)
         RepNCA.MIXmenu()
          }
    else {
     if (lambda_z_calc == 4){
-        cat("\n")
-        ## show(SingleRdata)   ### close this!  YJ
-        ## show(SingleTdata)
         RepTTTAIC.MIX(Dose, xaxis,yaxis,Totalplot,SingleRdata,SingleTdata,SingleRdata1,SingleTdata1)
         RepNCA.MIXmenu()
         }
@@ -169,12 +145,6 @@ create.products_sum(Totalplot)
      if(multiple){
       filelocxx <- system.file("extdata", "MultipleParadata.rda", package="bear")
       load(filelocxx)  ## because it is a *.rda data file; leave it as was
-      if(file.exists("MultiplePara_demo.csv")){
-         write.csv(MultipleParadata,file="MultiplePara_demo_02.csv",row.names=FALSE)}
-      else{write.csv(MultipleParadata,file="MultiplePara_demo.csv",row.names=FALSE)}
-      if(file.exists("MultiplePara_demo.RData")){
-         saveRDS(MultipleParadata,file="MultiplePara_demo_02.RData")}
-      else{saveRDS(MultipleParadata,file="MultiplePara_demo.RData")}
       
       with(Multiplentertitle.demo(), {
       description_ParaNCAinput()  
@@ -185,7 +155,7 @@ create.products_sum(Totalplot)
        SingleRdata0<-Refdata[ do.call(order, Refdata) ,]
        SingleRdata1<-Refdata[ do.call(order, Refdata) ,]
        SingleRdata1$conc[SingleRdata1$conc == 0] <- NA
-       SingleRdata1 <- na.omit(SingleRdata1)
+       ### SingleRdata1 <- na.omit(SingleRdata1)     ### for v2.6.1 IDP output function
       
       Test<-rbind(Singledata[[2]])
       Testdata<-data.frame(subj=Test$subj, drug=Test$drug, time=Test$time, conc=Test$conc)
@@ -193,10 +163,20 @@ create.products_sum(Totalplot)
        SingleTdata0<-Testdata[ do.call(order, Testdata) ,]
        SingleTdata1<-Testdata[ do.call(order, Testdata) ,]
        SingleTdata1$conc[SingleTdata1$conc == 0] <- NA
-       SingleTdata1 <- na.omit(SingleTdata1)
+       ### SingleTdata1 <- na.omit(SingleTdata1)     ### for v2.6.1 IDP output function
 
       SingleRdata<-subset(SingleRdata0, time >=TlastD)
+      show(SingleRdata0);cat("\n\n")
+        if(IndivDP_output){
+        SingleRTdata<-SingleRdata
+        indiv_dp.output(SingleRTdata)
+        }      
       SingleTdata<-subset(SingleTdata0, time >=TlastD)
+      show(SingleTdata0)
+        if(IndivDP_output){
+        SingleRTdata<-SingleTdata
+        indiv_dp.output(SingleRTdata)
+        }      
       
       Totalplot<- rbind(SingleRdata,SingleTdata)
 ###
@@ -205,49 +185,31 @@ create.products_sum(Totalplot)
       
     if (lambda_z_calc == 5){
         description_pointselect()
-        show(SingleRdata)
-        show(SingleTdata)
-        cat("\n")
         MultipleParaNCAselectdemo.MIX(Totalplot,SingleRdata1,SingleTdata1, Dose,SingleRdata,SingleTdata,xaxis, yaxis, Tau, TlastD,SingleRdata0,SingleTdata0)
         MultipleParaNCA.MIXmenu()
         }
     else {
     if (lambda_z_calc == 0){
-      show(SingleRdata)
-        show(SingleTdata)
-        cat("\n")
        MultipleParaARS.MIX(Dose, xaxis,yaxis,Totalplot,SingleRdata,SingleTdata,SingleRdata1,SingleTdata1, Tau, TlastD,SingleRdata0,SingleTdata0)
        MultipleParaNCA.MIXmenu()
        }
     else {
     if (lambda_z_calc == 1){
-        show(SingleRdata)
-        show(SingleTdata)
-        cat("\n")
        MultipleParaAIC.MIX(Dose, xaxis,yaxis,Totalplot,SingleRdata,SingleTdata,SingleRdata1,SingleTdata1, Tau, TlastD,SingleRdata0,SingleTdata0)
        MultipleParaNCA.MIXmenu()
        }
     else {
     if (lambda_z_calc == 2){
-        show(SingleRdata)
-        show(SingleTdata)
-        cat("\n")
        MultipleParaTTT.MIX(Dose, xaxis,yaxis,Totalplot,SingleRdata,SingleTdata,SingleRdata1,SingleTdata1, Tau, TlastD,SingleRdata0,SingleTdata0)
        MultipleParaNCA.MIXmenu()
        }
     else {
     if (lambda_z_calc == 3){
-        show(SingleRdata)
-        show(SingleTdata)
-        cat("\n")
        MultipleParaTTTARS.MIX(Dose, xaxis,yaxis,Totalplot,SingleRdata,SingleTdata,SingleRdata1,SingleTdata1, Tau, TlastD,SingleRdata0,SingleTdata0)
        MultipleParaNCA.MIXmenu()
        }
    else {
     if (lambda_z_calc == 4){
-        show(SingleRdata)
-        show(SingleTdata)
-        cat("\n")
        MultipleParaTTTAIC.MIX(Dose, xaxis,yaxis,Totalplot,SingleRdata,SingleTdata,SingleRdata1,SingleTdata1, Tau, TlastD,SingleRdata0,SingleTdata0)
        MultipleParaNCA.MIXmenu()
        }
@@ -261,12 +223,6 @@ create.products_sum(Totalplot)
     else{
      filelocxx <- system.file("extdata", "Paralleldata.rda", package="bear")
      load(filelocxx)  ## because it is a *.rda data file
-      if(file.exists("SinglePara_demo.csv")){
-         write.csv(Paralleldata,file="SinglePara_demo_02.csv",row.names=FALSE)}
-      else{write.csv(Paralleldata,file="SinglePara_demo.csv",row.names=FALSE)}
-      if(file.exists("SinglePara_demo.RData")){
-         saveRDS(Paralleldata,file="SinglePara_demo_02.RData")}
-      else{saveRDS(Paralleldata,file="SinglePara_demo.RData")}
      
      with(entertitle.demo(), {
      description_ParaNCAinput()  
@@ -274,18 +230,27 @@ create.products_sum(Totalplot)
       Ref<-Singledata[[1]]
       Refdata<-data.frame(subj=Ref$subj,drug=Ref$drug,time=Ref$time, conc=Ref$conc)
       SingleRdata<-Refdata[ do.call(order, Refdata) ,]
-      
+      show(SingleRdata);cat("\n\n")
+      if(IndivDP_output){
+      SingleRTdata<-SingleRdata
+      indiv_dp.output(SingleRTdata)
+      }
       SingleRdata1<-Refdata[ do.call(order, Refdata) ,]
       SingleRdata1$conc[SingleRdata1$conc == 0] <- NA
-      SingleRdata1 <- na.omit(SingleRdata1)
+      ### SingleRdata1 <- na.omit(SingleRdata1)     ### for v2.6.1 IDP output function
         cat("\n\n")
       Test<-rbind(Singledata[[2]])
       Testdata<-data.frame(subj=Test$subj, drug=Test$drug, time=Test$time, conc=Test$conc)
       SingleTdata<-Testdata[ do.call(order, Testdata) ,]
-      
+      show(SingleTdata)
+      if(IndivDP_output){
+      SingleRTdata<-SingleTdata
+      indiv_dp.output(SingleRTdata)
+      ###
+      }      
       SingleTdata1<-Testdata[ do.call(order, Testdata) ,]
       SingleTdata1$conc[SingleTdata1$conc == 0] <- NA
-      SingleTdata1 <- na.omit(SingleTdata1)
+      ### SingleTdata1 <- na.omit(SingleTdata1)     ### for v2.6.1 IDP output function
       Totalplot<- rbind(SingleRdata,SingleTdata)
 ###
 create.products_sum(Totalplot)
@@ -293,49 +258,31 @@ create.products_sum(Totalplot)
       
     if (lambda_z_calc == 5){
         description_pointselect()
-        cat("\n")
-        show(SingleRdata)
-        show(SingleTdata)
         ParaNCAselectdemo.MIX(Totalplot,SingleRdata1,SingleTdata1,Dose,SingleRdata,SingleTdata,xaxis, yaxis)
         ParaNCA.MIXmenu()
         }
     else {
     if (lambda_z_calc == 0){
-      cat("\n")
-        show(SingleRdata)
-        show(SingleTdata)
        ParaARS.MIX(Dose, xaxis,yaxis,Totalplot,SingleRdata,SingleTdata,SingleRdata1,SingleTdata1)
        ParaNCA.MIXmenu()
        }
     else {
     if (lambda_z_calc == 1){
-        cat("\n")
-        show(SingleRdata)
-        show(SingleTdata)
        ParaAIC.MIX(Dose, xaxis,yaxis,Totalplot,SingleRdata,SingleTdata,SingleRdata1,SingleTdata1)
        ParaNCA.MIXmenu()
        }
     else {
     if (lambda_z_calc == 2){
-        cat("\n")
-        show(SingleRdata)
-        show(SingleTdata) 
        ParaTTT.MIX(Dose, xaxis,yaxis,Totalplot,SingleRdata,SingleTdata,SingleRdata1,SingleTdata1)
        ParaNCA.MIXmenu()
        }
     else {
     if (lambda_z_calc == 3){
-        cat("\n")
-        show(SingleRdata)
-        show(SingleTdata)
        ParaTTTARS.MIX(Dose, xaxis,yaxis,Totalplot,SingleRdata,SingleTdata,SingleRdata1,SingleTdata1)
        ParaNCA.MIXmenu()
        }
    else {
     if (lambda_z_calc == 4){
-        cat("\n")
-        show(SingleRdata)
-        show(SingleTdata)
        ParaTTTAIC.MIX(Dose, xaxis,yaxis,Totalplot,SingleRdata,SingleTdata,SingleRdata1,SingleTdata1)
        ParaNCA.MIXmenu()
        }
@@ -351,12 +298,6 @@ create.products_sum(Totalplot)
      if(multiple){
      filelocxx <- system.file("extdata", "Multipledata.rda", package="bear")
      load(filelocxx)  ## because it is a *.rda data file
-     if(file.exists("Multiple2x2x2_demo.csv")){
-        write.csv(Multipledata,file="Multiple2x2x2_demo_02.csv",row.names=FALSE)}
-     else{write.csv(Multipledata,file="Multiple2x2x2_demo.csv",row.names=FALSE)}
-     if(file.exists("Multiple2x2x2_demo.RData")){
-        saveRDS(Multipledata,file="Multiple2x2x2_demo_02.RData")}
-     else{saveRDS(Multipledata,file="Multiple2x2x2_demo.RData")}     
      
      with(Multiplentertitle.demo(), {
      description_NCAinput()  
@@ -368,7 +309,7 @@ create.products_sum(Totalplot)
        SingleRdata0<-Refdata[ do.call(order, Refdata) ,]
        SingleRdata1<-Refdata[ do.call(order, Refdata) ,]
        SingleRdata1$conc[SingleRdata1$conc == 0] <- NA
-       SingleRdata1 <- na.omit(SingleRdata1)
+       ### SingleRdata1 <- na.omit(SingleRdata1)     ### for v2.6.1 IDP output function
         cat("\n\n")
       Test<-rbind(Singledata[[2]],Singledata[[3]])
       Testdata<-data.frame(subj=Test$subj, seq= Test$seq, prd=Test$prd, drug=c(2), 
@@ -376,60 +317,52 @@ create.products_sum(Totalplot)
        SingleTdata0<-Testdata[ do.call(order, Testdata) ,]
        SingleTdata1<-Testdata[ do.call(order, Testdata) ,]
        SingleTdata1$conc[SingleTdata1$conc == 0] <- NA
-       SingleTdata1 <- na.omit(SingleTdata1)
+       ### SingleTdata1 <- na.omit(SingleTdata1)     ### for v2.6.1 IDP output function
       
      SingleRdata<-subset(SingleRdata0, time >=TlastD)
+     show(SingleRdata0);cat("\n\n")   ### here show 'SingleRdata0' (original datset) not 'SingleRdata' since it is multiple-dose!
+      if(IndivDP_output){
+      SingleRTdata<-SingleRdata
+      indiv_dp.output(SingleRTdata)
+      }     
      SingleTdata<-subset(SingleTdata0, time >=TlastD)
+     show(SingleTdata0)
+      if(IndivDP_output){
+      SingleRTdata<-SingleTdata
+      indiv_dp.output(SingleRTdata)
+      }     
      Totalplot<- rbind(SingleRdata0,SingleTdata0)
 ###
 create.products_sum(Totalplot)
 ###
            
     if (lambda_z_calc == 5){
-        description_pointselect()
-        show(SingleRdata0)
-        show(SingleTdata0)
-        cat("\n")                 
+         description_pointselect()
          MultipleNCAselectdemo.BANOVA(Totalplot,SingleRdata1,SingleTdata1, Dose,SingleRdata,SingleTdata,xaxis, yaxis, Tau, TlastD,SingleRdata0,SingleTdata0) 
          MultipleNCA.BANOVAmenu()
         }
     else {
     if (lambda_z_calc == 0){
-        show(SingleRdata0)
-        show(SingleTdata0)
-        cat("\n")
-       MultipleARS.BANOVA(Dose, xaxis,yaxis,Totalplot,SingleRdata,SingleTdata,SingleRdata1,SingleTdata1, Tau, TlastD,SingleRdata0,SingleTdata0) 
+        MultipleARS.BANOVA(Dose, xaxis,yaxis,Totalplot,SingleRdata,SingleTdata,SingleRdata1,SingleTdata1, Tau, TlastD,SingleRdata0,SingleTdata0) 
         MultipleNCA.BANOVAmenu()
        }
     else {
     if (lambda_z_calc == 1){
-        show(SingleRdata0)
-        show(SingleTdata0)
-        cat("\n")
         MultipleAIC_BANOVA(Dose, xaxis,yaxis,Totalplot,SingleRdata,SingleTdata,SingleRdata1,SingleTdata1, Tau, TlastD,SingleRdata0,SingleTdata0) 
         MultipleNCA.BANOVAmenu()
        }
     else {
     if (lambda_z_calc == 2){
-        show(SingleRdata0)
-        show(SingleTdata0)
-        cat("\n")
         MultipleTTT.BANOVA(Dose, xaxis,yaxis,Totalplot,SingleRdata,SingleTdata,SingleRdata1,SingleTdata1, Tau, TlastD,SingleRdata0,SingleTdata0) 
         MultipleNCA.BANOVAmenu()
        }
     else {
     if (lambda_z_calc == 3){
-        show(SingleRdata0)
-        show(SingleTdata0)
-        cat("\n")
-       MultipleTTTARS.BANOVA(Dose, xaxis,yaxis,Totalplot,SingleRdata,SingleTdata,SingleRdata1,SingleTdata1, Tau, TlastD,SingleRdata0,SingleTdata0) 
+        MultipleTTTARS.BANOVA(Dose, xaxis,yaxis,Totalplot,SingleRdata,SingleTdata,SingleRdata1,SingleTdata1, Tau, TlastD,SingleRdata0,SingleTdata0) 
         MultipleNCA.BANOVAmenu()
        }
    else {
     if (lambda_z_calc == 4){
-        show(SingleRdata0)
-        show(SingleTdata0)
-        cat("\n")
        MultipleTTTAIC.BANOVA(Dose, xaxis,yaxis,Totalplot,SingleRdata,SingleTdata,SingleRdata1,SingleTdata1, Tau, TlastD,SingleRdata0,SingleTdata0) 
        MultipleNCA.BANOVAmenu()
        }
@@ -442,14 +375,10 @@ create.products_sum(Totalplot)
  }
    else{
     description_NCAinput()
-    filelocxx <- system.file("extdata", "TotalSingledata.rda", package="bear")
-    load(filelocxx)  ## because it is a *.rda data file
-    if(file.exists("Single2x2x2_demo.csv")){
-       write.csv(TotalSingledata,file="Single2x2x2_demo_02.csv",row.names=FALSE)}
-    else{write.csv(TotalSingledata,file="Single2x2x2_demo.csv",row.names=FALSE)}
-    if(file.exists("Single2x2x2_demo.RData")){
-       saveRDS(TotalSingledata,file="Single2x2x2_demo_02.RData")}
-    else{saveRDS(TotalSingledata,file="Single2x2x2_demo.RData")}         
+    filelocxx <- system.file("extdata", "TotalSingledata.rda", package="bear")   ### both work well.
+    load(filelocxx)  ## because it is a *.rda data file                      
+    ### filelocxx <- system.file("extdata", "Single2x2x2.rda", package="bear")   ### v2.6.1 to test IDP function
+    ### TotalSingledata<-readRDS(filelocxx)
     
     cat("\n\n")
      ##NCAanalyze or NCAGLManalyze
@@ -460,70 +389,60 @@ create.products_sum(Totalplot)
       Ref<-rbind(Singledata[[1]],Singledata[[4]])
       Refdata<-data.frame(subj=Ref$subj, seq= Ref$seq, prd=Ref$prd, drug=c(1), time=Ref$time, conc=Ref$conc)
       SingleRdata<-Refdata[ do.call(order, Refdata) ,]
-      
+      show(SingleRdata);cat("\n\n")
+      if(IndivDP_output){
+      SingleRTdata<-SingleRdata
+      indiv_dp.output(SingleRTdata)
+      }      
       SingleRdata1<-Refdata[ do.call(order, Refdata) ,]
       SingleRdata1$conc[SingleRdata1$conc == 0] <- NA
-      SingleRdata1 <- na.omit(SingleRdata1)
-        cat("\n\n")
+      ### SingleRdata1 <- na.omit(SingleRdata1)     ### for v2.6.1 IDP output function
+      cat("\n\n")
       Test<-rbind(Singledata[[2]],Singledata[[3]])
       Testdata<-data.frame(subj=Test$subj, seq= Test$seq, prd=Test$prd, drug=c(2), time=Test$time, conc=Test$conc)
       SingleTdata<-Testdata[ do.call(order, Testdata) ,]
-      
+      show(SingleTdata)
+      if(IndivDP_output){
+      SingleRTdata<-SingleTdata
+      indiv_dp.output(SingleRTdata)
+      }      
       SingleTdata1<-Testdata[ do.call(order, Testdata) ,]
       SingleTdata1$conc[SingleTdata1$conc == 0] <- NA
-      SingleTdata1 <- na.omit(SingleTdata1)
+      ### SingleTdata1 <- na.omit(SingleTdata1)     ### for v2.6.1 IDP output function
       Totalplot<- rbind(SingleRdata,SingleTdata)
 ###
 create.products_sum(Totalplot)
 ###
 
     if (lambda_z_calc == 5){
-      cat("\n")
         description_pointselect()
-        show(SingleRdata)
-        show(SingleTdata)
         NCAselectdemo.BANOVA(Totalplot,SingleRdata1,SingleTdata1,Dose,SingleRdata,SingleTdata,xaxis, yaxis)
         NCA.BANOVAmenu()
         }
 
     else {
     if (lambda_z_calc == 0){
-        cat("\n")
-        show(SingleRdata)
-        show(SingleTdata)
         ARS.BANOVA(Dose, xaxis,yaxis,Totalplot,SingleRdata,SingleTdata,SingleRdata1,SingleTdata1)
         NCA.BANOVAmenu()
        }
        
     else {
     if (lambda_z_calc == 1){
-        cat("\n")
-        show(SingleRdata)
-        show(SingleTdata)
         AIC_BANOVA(Dose, xaxis,yaxis,Totalplot,SingleRdata,SingleTdata,SingleRdata1,SingleTdata1)
         NCA.BANOVAmenu()
        }
     else {
     if (lambda_z_calc == 2){
-        cat("\n")
-        show(SingleRdata)
-        show(SingleTdata)
         TTT.BANOVA(Dose, xaxis,yaxis,Totalplot,SingleRdata,SingleTdata,SingleRdata1,SingleTdata1)
         NCA.BANOVAmenu()
        }
     else {
     if (lambda_z_calc == 3){
-        cat("\n")
-        show(SingleRdata)
-        show(SingleTdata)
         TTTARS.BANOVA(Dose, xaxis,yaxis,Totalplot,SingleRdata,SingleTdata,SingleRdata1,SingleTdata1)
         NCA.BANOVAmenu()
          }
    else {
     if (lambda_z_calc == 4){
-        cat("\n")
-        show(SingleRdata)
-        show(SingleTdata)
         TTTAIC.BANOVA(Dose, xaxis,yaxis,Totalplot,SingleRdata,SingleTdata,SingleRdata1,SingleTdata1)
         NCA.BANOVAmenu()
         }
