@@ -16,6 +16,7 @@ pAUC<-pAUC
 pAUC_start<-pAUC_start
 pAUC_end<-pAUC_end
 designtrace<-designtrace
+IndivDP_output<-IndivDP_output
 
 ### for debug ###
 ## cat("\n BE_UL =",BE_UL,"\n\n")
@@ -26,15 +27,14 @@ designtrace<-designtrace
 ###
 
   cat("\n*** You have selected the following -> (new)\n")
-  file.menu <- c("- Single dose study",
+  file.menu <- c("* Single dose study",
                  "- Multiple dose study",
-                 "* Single dose study   (with ODA)",
-                 "* Multiple dose study (with ODA)",
-                 "# Edit the setup files (if necessary)",
-                 "# Genearate/export all demo datasets",
-                 "% Quit",
-                 "ps. ODA: outlier detection analysis 
-   (not recommended for routine use!)")
+                 "* Single dose study (with ODA)",
+                 "- Multiple dose study (with ODA)",
+                 "* Edit the setup files (if necessary)",
+                 "- Genearate/export all demo datasets",
+                 "# Quit",
+                 "* View cheatsheet for bear setting")
    cat("\n")
   pick <- menu(file.menu, title = " << Top menu (select from 1~7) >> ", graphics=TRUE)
     if (pick == 1){
@@ -74,25 +74,32 @@ designtrace<-designtrace
        
     if (pick == 5){
         graphics.off()
-        cat("*** Please read following messages first. ***\n\n")
-        cat("(1) After selecting [# Edit the setup files], users\n")
-        cat("    can scroll up this terminal to see more.\n")
-        cat("(2) Please close this (linux distro users click\n")
-        cat("    'x', not 'Quit') directly if use defaults.\n\n")
-        readline(" Press Enter to proceed...\n")
+        ### readme.1st.bear<- system.file("extdata", "bear_setup_readme.txt", package="bear")
+        ### file.show(readme.1st.bear,title="How to setup bear",encoding="UTF-8")    ### linux OS cannot work properly... -YJ
         bear.set<-readRDS("bear.setup.rds");bear.set<-edit(bear.set)
         while(bear.set[8,2]>bear.set[9,2]){
-        readline("\n Error! pAUC_start must be less than pAUC_end!\n Press Enter to fix it...\n")
+        readline("\n Error! pAUC_start must be less than pAUC_end!\n Press Enter to fix it.\n")
+        bear.set<-edit(bear.set)}
+        if(bear.set[1,2]<0 || bear.set[1,2]>6) bear.set[1,2]<-0
+        if(bear.set[2,2]<0) {bear.set[2,2]<-0}
+         else {if(bear.set[2,2]>0) bear.set[2,2]<-1}
+        if(bear.set[10,2]<0) bear.set[10,2]<-0
+         else {if(bear.set[10,2]>0) bear.set[10,2]<-1}
+        if(bear.set[3,2]<50 || bear.set[3,2]>90) bear.set[3,2]<-80
+        if(bear.set[7,2]<0 || bear.set[7,2]>0) bear.set[7,2]<-1
+        while(bear.set[4,2]<0 || bear.set[5,2]<0 || bear.set[6,2]<0){
+        readline("\n Error! Dose, Dosing interval or the last time of dosing\n cannot be less than zero! Press Enter to fix it.\n")
         bear.set<-edit(bear.set)}
         saveRDS(bear.set,"bear.setup.rds")
         plotz.set<-readRDS("plot.setup.rds")
         secondColumn<-as.character(plotz.set[,2])    ### to remove 'level' from a list of data.frame(). ---YJ
-        xlabzz<-readline( " The label of x-axis: ")
+        xlabzz<-readline( "             The label of x-axis (time): ")
         if(xlabzz=="") xlabzz<-secondColumn[[1]]     ### if just press Enter key, no change will be made.
-        ylabzz<-readline( " the label of y-axis: ")
+        ylabzz<-readline( " the label of y-axis (drug plasma conc): ")
         if(ylabzz=="") ylabzz<-secondColumn[[2]]     ### if just press Enter key, no change will be made.
         plotz.set<-data.frame(axis_label=c("x-axis","y-axis"),Setting=c(xlabzz,ylabzz))
         saveRDS(plotz.set,"plot.setup.rds");cat("\n\n")
+        ### close("R Information")   ### don't work?  how to close this?
         go2menu()
        }
 
@@ -109,7 +116,10 @@ designtrace<-designtrace
        
     if (pick == 8){
         cat("\n")
-        alarm();readline("... Uhh? invalid selection. Press Enter and try again.\n")
+        ### alarm();readline("... Uhh? invalid selection. Press Enter and try again.\n")
+        readme.1st.bear<- system.file("extdata", "bear_setup_readme.txt", package="bear")
+        file.show(readme.1st.bear,title="How to setup bear",encoding="UTF-8")    ### linux OS cannot work properly... -YJ
+        readline("\n\n... Press Enter to continue.")
         graphics.off()
         go2menu()
        }
